fn recursive_normalize(
use_tree: UseTree,
style: NormalizationStyle,
make: &SyntaxFactory,
) -> Option<UseTree>Expand description
Recursively normalizes a use tree and its subtrees (if any).
fn recursive_normalize(
use_tree: UseTree,
style: NormalizationStyle,
make: &SyntaxFactory,
) -> Option<UseTree>Recursively normalizes a use tree and its subtrees (if any).